function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React from 'react';
import useSize from './hooks/useSize';
var EChartsCore = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var echarts = props.echarts,
      className = props.className,
      style = props.style,
      option = props.option,
      theme = props.theme,
      initOpts = props.initOpts,
      setOptionOpts = props.setOptionOpts,
      autoResize = props.autoResize,
      loading = props.loading,
      loadingConfig = props.loadingConfig,
      onChartInit = props.onChartInit,
      onEvents = props.onEvents;
  var echartsContainerRef = React.useRef(null);
  var echartsInstanceRef = React.useRef(null);

  var _useSize = useSize(echartsContainerRef.current || document.body),
      width = _useSize.width,
      height = _useSize.height;

  React.useImperativeHandle(ref, function () {
    return {
      get echartsInstance() {
        return echartsInstanceRef.current;
      }

    };
  });
  /**
   * 创建ECharts实例
   */

  var initECharts = function initECharts() {
    if (echartsContainerRef.current) {
      echartsInstanceRef.current = echarts.init(echartsContainerRef.current, theme, initOpts);

      if (onChartInit) {
        onChartInit(echartsInstanceRef.current);
      }

      buildEvents();
      setOption();
    }
  };
  /**
   * 销毁ECharts实例
   */


  var disposeECharts = function disposeECharts() {
    if (echartsInstanceRef.current) {
      echartsInstanceRef.current.dispose();
      echartsInstanceRef.current = null;
    }
  };
  /**
   * 绑定事件
   */


  var buildEvents = function buildEvents() {
    Object.entries(onEvents || {}).forEach(function (_ref) {
      var _ref2 = _slicedToArray(_ref, 2),
          eventName = _ref2[0],
          handler = _ref2[1];

      if (echartsInstanceRef.current) {
        echartsInstanceRef.current.on(eventName, handler);
      }
    });
  };
  /**
   * 设置图表配置项
   */


  var setOption = function setOption() {
    if (echartsInstanceRef.current && option) {
      echartsInstanceRef.current.setOption(option, setOptionOpts);
    }
  };
  /**
   * 调整大小
   */


  var resize = function resize() {
    if (autoResize && echartsInstanceRef.current) {
      echartsInstanceRef.current.resize();
    }
  };
  /**
   * 切换Loading
   */


  var toggleLoading = function toggleLoading() {
    if (echartsInstanceRef.current) {
      if (loading) {
        echartsInstanceRef.current.showLoading(loadingConfig === null || loadingConfig === void 0 ? void 0 : loadingConfig.type, loadingConfig === null || loadingConfig === void 0 ? void 0 : loadingConfig.opts);
      } else {
        echartsInstanceRef.current.hideLoading();
      }
    }
  };

  React.useEffect(function () {
    initECharts();
    return function () {
      disposeECharts();
    };
  }, [echartsContainerRef, theme, initOpts]);
  React.useEffect(function () {
    setOption();
  }, [option]);
  React.useLayoutEffect(function () {
    resize();
  }, [width, height]);
  React.useEffect(function () {
    toggleLoading();
  }, [loading]);
  return /*#__PURE__*/React.createElement("div", {
    ref: echartsContainerRef,
    className: className,
    style: style
  });
});
EChartsCore.defaultProps = {
  autoResize: false,
  loading: false
};
export default EChartsCore;